package com.yizhi.live.application.feign;


import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.core.application.vo.DroolsVo;
import com.yizhi.live.application.request.LiveReleaseReviewReq;
import com.yizhi.live.application.vo.*;
import com.yizhi.util.application.domain.BizResponse;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.Date;
import java.util.List;
import java.util.Map;

@FeignClient(name = "live", contextId = "LiveActivityClient")
public interface LiveActivityClient {

    /**
     * 获取直播的频道号
     * @param id
     * @return
     */
    @GetMapping("/manage/live/channelNo/get")
    public String getChannelNo(@RequestParam("id") Long id);

    @PostMapping("/manage/live/save")
    Boolean save(@RequestBody LiveActivityResultVO liveActivityResultVO);


    /**
     * 管理端 直播列表查询feign接口
     *
     * @param title     主题
     * @param companyId 企业id
     * @param siteId    站点id
     * @param orgIds    管辖区id
     * @param pageNo    分页的页数
     * @param pageSize  分页的条数
     * @return PageLiveVo 前台展示对象
     */
    @GetMapping("/manage/live/list")
    Page<PageLiveVo> list(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTimeString", required = false) String startTimeString,
            @RequestParam(name = "endTimeString", required = false) String endTimeString,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize,
            @RequestParam(name = "expTimeString", required = false) String expTimeString,
            @RequestParam(name = "status" ,required = false) Integer status,
            @RequestParam(name = "viewType", required = false) Integer viewType
    );
    @GetMapping("/manage/live/v2/list")
    Page<PageLiveVo> listV2(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTimeString", required = false) String startTimeString,
            @RequestParam(name = "endTimeString", required = false) String endTimeString,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize,
            @RequestParam(name = "expTimeString", required = false) String expTimeString,
            @RequestParam(name = "status" ,required = false) Integer status,
            @RequestParam(name = "viewType", required = false) Integer viewType,
            @RequestParam(name = "startTimeAsc",required = false) Boolean startTimeAsc,
            @RequestParam(name = "endTimeAsc",required = false) Boolean endTimeAsc
    );

    @GetMapping("/remote/live/sevenDays/get")
    List<LiveActivityVO> findWithinSevenDaysLive();

    /**
     *  首页配置选择直播列表
     * @param title     主题
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @param companyId 企业id
     * @param siteId    站点id
     * @param orgIds    管辖区id
     * @param pageNo    分页的页数
     * @param pageSize  分页的条数
     * @return PageLiveVo 前台展示对象
     * @return List<PageLiveVo>
     */
    @GetMapping("/manage/live/portal/list")
    List<PageLiveVo> portalList(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTime", required = false) Date startTime,
            @RequestParam(name = "endTime", required = false) Date endTime,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    );

    @GetMapping("/manage/live/portal/v2/list")
    public Page<PageLiveVo> portalListV2(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTime", required = false) Date startTime,
            @RequestParam(name = "endTime", required = false) Date endTime,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    );


    @PostMapping("/manage/live/delete")
    Boolean delete(
            @RequestBody LiveActivityVO liveActivity
    );

    @GetMapping("/manage/live/get")
    LiveActivityResultVO get(@RequestParam("id") Long id);

    /**
     * 获取直播实体
     * @param id
     * @return
     */
    @GetMapping("/manage/live/getLive")
    LiveActivityVO getLive(@RequestParam("id") Long id);

    @PostMapping("/manage/live/signature")
    LiveAppIdVo signature();

    @GetMapping("/manage/live/api/list")
    List<PageLiveVo> apiList(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "ids", required = false) List<Long> ids,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    );

    @GetMapping("/manage/live/api/pageList")
    Page<PageLiveVo> apiPageList(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "ids", required = false) List<Long> ids,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    );

    @PostMapping("/manage/live/token")
    String getToken(@RequestBody LiveTokenVo liveTokenVo);


    /**
     * 直播指定范围保存
     *
     * @param scopeAuthorizations
     * @return
     */
    @PostMapping("/manage/live/scopeAuthorization/save")
    Boolean saveScopeAuthorization(@RequestBody List<ScopeAuthorizationVO> scopeAuthorizations);

    /**
     * 直播指定范围保存，不删除之前的记录
     *
     * @param scopeAuthorizations
     * @return
     */
    @PostMapping("/manage/live/scopeAuthorization/insert")
    Boolean insertScopeAuthorization(@RequestBody List<ScopeAuthorizationVO> scopeAuthorizations);

    /**
     * 已保存的指定范围集合
     *
     * @param liveId
     * @return
     */
    @GetMapping("/manage/live/scopeAuthorization/list")
    List<ScopeAuthorizationVO> getScopeAuthorizationList(@RequestParam(name = "liveId") Long liveId);

    /**
     * 直播上架
     *
     * @param param 带id
     * @return
     */
    @PostMapping("/manage/live/up")
    Boolean up(@RequestBody LiveActivityVO param);

    /**
     * 直播下架
     *
     * @param param 只带id
     * @return
     */
    @PostMapping("/manage/live/down")
    Boolean down(@RequestBody LiveActivityVO param);

    /**
     *  直播修改信息
     * @param liveActivityResultVO
     * @return
     */
    @PostMapping("/manage/live/update")
    Boolean update(
            @RequestBody LiveActivityResultVO liveActivityResultVO
    );

    /**
     * 根据频道id获得直播信息
     */
    @GetMapping("/manage/live/channelId/view")
    LiveActivityVO viewByChannelId(@RequestParam(name = "channelId") String channelId);
    
    
    
    /**
	  * 可见范围导出
	  * @param assignmentId
	  * @return
	  */
	 @GetMapping("/manage/live/export/visiblRange")
	 public VisibleRangeExport exportVisibleRange(@RequestParam(name="liveId",required=true)Long liveId);


    @PostMapping("/manage/live/access/lives")
    public List<Long> accessLives(@RequestBody AccessLiveVO vo);

    @GetMapping("/manage/live/pc/pageList")
    public Page<PageLiveVo> pcPageList(@RequestParam(name = "title", required = false) String title,
                                       @RequestParam(name = "ids", required = false) List<Long> ids,
                                       @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                       @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize);

    /**
     * 根据站点Id查询直播列表
     * @param siteId
     * @param pageNo
     * @param pageSize
     * @return
     */
    @GetMapping("/manage/live/pc/getPage")
    public Page<PageLiveVo> getPageLiveVoList(@RequestParam(name = "siteId", required = false) Long siteId,
                                              @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                              @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize);
    
    
    @GetMapping("/manage/live/pc/getPage/notIds")
    public Page<LiveActivityVO> getPageLiveVoListNotIds(
    		                                  @RequestParam(name = "ids", required = false) List<Long> ids,
    		                                  @RequestParam(name = "siteId", required = false) Long siteId,
                                              @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                              @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize);


    /**
     * 根据relationId 判断这个人是否可以看到这这场直播
     *
     * @param relationId 里面有accountId or orgId
     * @param liveId     直播Id
     * @return
     */
    @GetMapping("/manage/live/pc/judgeScope")
    public Boolean judgeScope(@RequestParam(name = "relationId", required = false) List<Long> relationId,
                              @RequestParam(name = "liveId", required = false) Long liveId);




    /**
     * 根据直播Id查看直播信息
     *
     * @param liveId
     * @return
     */
    @GetMapping("/manage/live/pc/queryLive")
    public LiveActivityVO queryLive(@RequestParam(name = "liveId") Long liveId);
    
    
    @GetMapping("/manage/live/pc/queryLive/byIds")
    public Page<LiveActivityVO> LiveActivityByIds(@RequestParam(value="listIds",required=false)List<Long> listIds, @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize);

    /**
     * 根据传入的relationIds 里面有accountId、orgId
     * @param relationIds
     * @param pageNo
     * @param pageSize
     * @return
     */
    @PostMapping("/manage/live/pc/queryLiveListByRelationIds")
    public List<PageLiveVo> queryLiveListByRelationIds(@ApiParam(value = "relationIds 里面有accountId、orgId")
                                                       @RequestParam(value = "relationIds 里面有accountId、orgId",required = false) List<Long> relationIds,
                                                       @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                       @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize);
    /**
     * 根据传入的频道Id,返回直播状态
     * @param channelId
     * @return   1--即将开始  2--live 直播中 3-end 直播结束  -1 获取状态异常
     */
    @GetMapping("/manage/live/pc/getLiveStatus")
    public Integer getLiveStatus(@ApiParam(value ="channelId 频道Id" )@RequestParam(value ="channelId" ) String channelId);
    
    @GetMapping("/manage/live/by/new/server")
    public List<Map<String,Object>> getServerByCompanyIdAndIds(@RequestParam("companyId")Long companyId,@RequestParam(name="ids",required=false)List<Long> ids);


    @GetMapping("/manage/live/scope/message/getList")
    public VisibleRangeExport getListToMessage(@RequestParam("liveId") Long liveId);

    @PostMapping("/manage/live/getPageToCalendar")
    public Page<PageLiveVo> getPageToCalendar(@ApiParam("paramVo") @RequestBody CalendarTaskParamVo paramVo);

    @GetMapping("/manage/live/getPageByDrools")
    Page<DroolsVo> getPageByDrools(@RequestParam("field") String field,
                                   @RequestParam(value = "value", required = false) String value,
                                   @RequestParam("pageNo") Integer pageNo,
                                   @RequestParam("pageSize") Integer pageSize);


        @GetMapping("/remote/live/statistics/online/count/realtime")
        @ApiOperation(value = "实时查询直播在线人数;多个频道用逗号隔开")
        public List<LiveOnlineCountVo> liveCountOnlineRealTime(@RequestParam("channelIds") String channelIds) ;

        @GetMapping("/remote/live/status/callback")
        @ApiOperation(value = "直播状态改变,保利威回调接口")
        public BizResponse liveStatusCallback(@RequestParam(value = "channelId") String channelId
                , @RequestParam(value = "status") String status
                , @RequestParam(value = "timestamp") Long timestamp
                , @RequestParam(value = "sign") String sign
                , @RequestParam(value = "sessionId") String sessionId
                , @RequestParam(value = "startTime") String startTime
                , @RequestParam(value = "endTime") String endTime);


        @GetMapping("/remote/live/play/review/list")
        @ApiOperation(value = "查询直播回放列表")
        public Page<LiveReplayVo> playReviewList(@RequestBody LiveReviewListVo liveReviewListVo) ;

        @GetMapping("/remote/live/review/switch/on/live/list")
        @ApiOperation(value = "查询有直播回放的直播间列表 废弃!!!")
        public BizResponse<List<LiveTitleVo>> reviewLiveList(@RequestBody LiveReviewsVo liveReviewsVo);

        @GetMapping("/remote/live/reviews/get")
        @ApiOperation(value = "根据直播间查询上架的直播回放")
        public BizResponse<List<LiveReplayVo>> reviewsList(@RequestBody LiveReviewsVo liveReviewsVo);

        @GetMapping("/remote/live/review/one/get")
        @ApiOperation(value = "查询直播回放详情")
        public BizResponse<LiveReplayVo> getReview(@RequestParam(name = "replayId") Long replayId);

        @GetMapping("/remote/live/review/switch/on/live/page/list")
        @ApiOperation(value = "分页查询有直播回放的直播间列表")
        public Page<LiveTitleVo> getHasReplayLiveList(@RequestBody LiveReleaseReviewReq replayVo);

        @PostMapping("/remote/live/release/replay/list")
        @ApiOperation(value = "查询所有上架的直播回放列表")
        public Page<LiveReplayVo> getReleaseReplayList(@RequestBody LiveReleaseReviewReq reviewReq);


}

